@@ -1,4 +1,5 @@
 import os
+from pwd import getpwnam  
 import sys
 import click
 import tempfile
@@ -43,7 +44,12 @@ def _export_settings(config, forced_values):
     # constants
     settings = MyConfigParser(config.files['settings'])
     if 'OWNER_UID' not in settings.keys():
-        settings['OWNER_UID'] = str(os.getenv("SUDO_UID", os.getuid()))
+        UID = int(os.getenv("SUDO_UID", os.getuid()))
+        if not UID:
+            # sometimes (in ansible) SUDO_UID is set to 0 but env USER exists
+            if os.getenv("USER") and os.environ['USER'] != 'root':
+                UID = getpwnam(os.environ['USER']).pw_uid
+        settings['OWNER_UID'] = str(UID)
 
     # forced values:
     for k, v in forced_values.items():
